/*
 * cms.c
 *
 * Copyright 2022 Jonathan Schöbel <jonathan@Ubermos-2019>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 *
 *
 */


#include <stdlib.h>

#include "macro.h"
#include "error.h"
#include "log.h"

#include "data.h"

#include "cms.h"


struct SH_Cms *
SH_Cms_new (struct SH_Error * error)
{
	struct SH_Cms * cms;
	cms = malloc (sizeof (struct SH_Cms));

	if (cms == NULL)
	{
		ERROR1 ("Memory allocation for SH_Cms failed.\n");

		if (error != NULL)
		{
			error->type = ALLOCATION_FAILED;
		}

		return NULL;
	}

	cms->data = SH_Data_new (error);

	if (cms->data == NULL)
	{
		return NULL;
	}

	if (error != NULL)
	{
		error->type = SUCCESS;
	}

	return cms;
}

void
SH_Cms_free (struct SH_Cms * cms, struct SH_Error * error)
{
	SH_Data_free (cms->data, NULL);

	free (cms);

	if (error != NULL)
	{
		error->type = SUCCESS;
	}

	return;
}

page_t
SH_Cms_register_page (struct SH_Cms * cms, const char * name,
		      struct SH_Error * error)
{
	return SH_Data_register_page (cms->data, name, error);
}
