/*
 * validator.h
 *
 * Copyright 2022 Jonathan Schöbel <jonathan@Ubermos-2019>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 *
 *
 */


#ifndef _VALIDATOR_H
#define _VALIDATOR_H

#include <limits.h>
#include <stdbool.h>


typedef unsigned int tag_t;
#define TAG_ERR 0
#define TAG_MIN 1
#define TAG_MAX UINT_MAX
#define NEXT_TAG(tag) tag++

struct SH_Tag
{
	tag_t id;
	char * name;
};

struct SH_Validator
{
	unsigned int tag_n;
	struct SH_Tag * tags;
	tag_t last_tag;
};

struct SH_Validator * SH_Validator_new (struct SH_Error * error);
void SH_Validator_free (struct SH_Validator * validator,
			struct SH_Error * error);

tag_t SH_Validator_register_tag (struct SH_Validator * validator,
				 const char * tag,
				 struct SH_Error * error);


bool SH_Validator_check_tag (struct SH_Validator * validator,
			     const char * tag);

#endif /* _VALIDATOR_H */
